@@ -29,11 +29,11 @@ class ShardedModel(StorableModel):
     def _db(self):
         return ctx.db.shards[self._shard_id]
 
-    def save(self, skip_callback=False):
+    def save(self, skip_callback=False, invalidate_cache=True):
         if self._shard_id is None:
             raise MissingShardId(
                 "ShardedModel must have shard_id set before save")
-        super().save(skip_callback)
+        super().save(skip_callback, invalidate_cache)
 
     def _refetch_from_db(self):
         return self.find_one(self._shard_id, {"_id": self._id})
@@ -109,8 +109,10 @@ class ShardedModel(StorableModel):
         obj.shard_id = shard_id
         return obj
 
-    def invalidate(self):
-        cache_key_id = f"{self.collection}.{self._shard_id}.{self._id}"
+    def invalidate(self, _id=None):
+        if _id is None:
+            _id = self._id
+        cache_key_id = f"{self.collection}.{self._shard_id}.{_id}"
         cache_key_keyfield = None
         if self.KEY_FIELD is not None and self.KEY_FIELD != "_id":
             cache_key_keyfield = f"{self.collection}.{self._shard_id}.{getattr(self, self.KEY_FIELD)}"
