@@ -1,4 +1,3 @@
-from {{project_name}}.models import User, Token
 import logging
 import mongomock
 
@@ -6,7 +5,6 @@ from commands import Command, _all_tests
 from unittest import main
 from uengine import ctx
 from {{project_name}} import force_init_app
-from {{project_name}} import tests
 
 
 class Test(Command):
@@ -16,6 +14,8 @@ class Test(Command):
     @mongomock.patch()
     def run(self):
         force_init_app()
+        del ctx.queue
+        ctx.queue = DummyQueue({})
         ctx.log.setLevel(logging.ERROR)
         argv = ['micro.py test', '--buffer'] + self.raw_args
         test_program = main(argv=argv, module=_all_tests, exit=False)
